@@ -311,7 +311,9 @@ class SerializerBase(object):
                 value["__class__"] = obj.__class__.__module__ + "." + obj.__class__.__name__
                 return value
             else:
-                raise errors.SerializeError("don't know how to serialize class " + str(obj.__class__) + " using serializer " + str(cls.__name__) + ". Give it vars() or an appropriate __getstate__")
+                raise errors.SerializeError("don't know how to serialize class " + str(obj.__class__) +
+                                            " using serializer " + str(cls.__name__) +
+                                            ". Give it vars() or an appropriate __getstate__")
 
     @classmethod
     def dict_to_class(cls, data):
@@ -354,6 +356,8 @@ class SerializerBase(object):
                 return JsonSerializer()
             elif classname == "Pyro4.util.MsgpackSerializer":
                 return MsgpackSerializer()
+            elif classname == "Pyro4.util.CloudpickleSerializer":
+                return CloudpickleSerializer()
             elif classname == "Pyro4.util.DillSerializer":
                 return DillSerializer()
         elif classname.startswith("Pyro4.errors."):
@@ -457,6 +461,36 @@ class PickleSerializer(SerializerBase):
             pass
 
 
+class CloudpickleSerializer(SerializerBase):
+    """
+    A (de)serializer that wraps the Cloudpickle serialization protocol.
+    It can optionally compress the serialized data, and is thread safe.
+    """
+    serializer_id = 7  # never change this
+
+    def dumpsCall(self, obj, method, vargs, kwargs):
+        return cloudpickle.dumps((obj, method, vargs, kwargs), config.PICKLE_PROTOCOL_VERSION)
+
+    def dumps(self, data):
+        return cloudpickle.dumps(data, config.PICKLE_PROTOCOL_VERSION)
+
+    def loadsCall(self, data):
+        return cloudpickle.loads(data)
+
+    def loads(self, data):
+        return cloudpickle.loads(data)
+
+    @classmethod
+    def register_type_replacement(cls, object_type, replacement_function):
+        def copyreg_function(obj):
+            return replacement_function(obj).__reduce__()
+
+        try:
+            copyreg.pickle(object_type, copyreg_function)
+        except TypeError:
+            pass
+
+
 class DillSerializer(SerializerBase):
     """
     A (de)serializer that wraps the Dill serialization protocol.
@@ -680,7 +714,7 @@ class MsgpackSerializer(SerializerBase):
             return datetime.datetime.fromtimestamp(struct.unpack("d", data)[0])
         if code == 0x33:
             return datetime.date.fromordinal(struct.unpack("l", data)[0])
-        raise errors.SerializeError("invalid ext code for msgpack: "+str(code))
+        raise errors.SerializeError("invalid ext code for msgpack: " + str(code))
 
     @classmethod
     def register_type_replacement(cls, object_type, replacement_function):
@@ -718,6 +752,13 @@ import marshal
 _ser = MarshalSerializer()
 _serializers["marshal"] = _ser
 _serializers_by_id[_ser.serializer_id] = _ser
+try:
+    import cloudpickle
+    _ser = CloudpickleSerializer()
+    _serializers["cloudpickle"] = _ser
+    _serializers_by_id[_ser.serializer_id] = _ser
+except ImportError:
+    pass
 try:
     import dill
     _ser = DillSerializer()
@@ -809,6 +850,7 @@ def fixIronPythonExceptionForPickle(exceptionObject, addAttributes):
 
 __exposed_member_cache = {}
 
+
 def reset_exposed_members(obj, only_exposed=True, as_lists=False):
     """Delete any cached exposed members forcing recalculation on next request"""
     if not inspect.isclass(obj):
@@ -816,6 +858,7 @@ def reset_exposed_members(obj, only_exposed=True, as_lists=False):
     cache_key = (obj, only_exposed, as_lists)
     __exposed_member_cache.pop(cache_key, None)
 
+
 def get_exposed_members(obj, only_exposed=True, as_lists=False, use_cache=True):
     """
     Return public and exposed members of the given object's class.
@@ -902,7 +945,7 @@ def set_exposed_property_value(obj, propname, value, only_exposed=True):
 _private_dunder_methods = frozenset([
     "__init__", "__call__", "__new__", "__del__", "__repr__", "__unicode__",
     "__str__", "__format__", "__nonzero__", "__bool__", "__coerce__",
-    "__cmp__", "__eq__", "__ne__", "__hash__",
+    "__cmp__", "__eq__", "__ne__", "__hash__", "__ge__", "__gt__", "__le__", "__lt__",
     "__dir__", "__enter__", "__exit__", "__copy__", "__deepcopy__", "__sizeof__",
     "__getattr__", "__setattr__", "__hasattr__", "__getattribute__", "__delattr__",
     "__instancecheck__", "__subclasscheck__", "__getinitargs__", "__getnewargs__",
